from __future__ import absolute_import, unicode_literals

import json

from django.conf import settings
from django.contrib.staticfiles.templatetags.staticfiles import static
from django.forms import Media, widgets

from wagtail.utils.widgets import WidgetWithScript
from wagtail.wagtailadmin.edit_handlers import RichTextFieldPanel
from wagtail.wagtailcore.rich_text import DbWhitelister, expand_db_html


class FroalaRichTextArea(WidgetWithScript, widgets.Textarea):
    def __init__(self, **kwargs):
        try:
            self.options = kwargs.pop('options')
        except KeyError:
            self.options = {
                'key': settings.FROALA_LICENSE_KEY
            }
            self.options.update(getattr(settings, 'FROALA_OPTIONS', {}))

        super(FroalaRichTextArea, self).__init__(**kwargs)

    def get_panel(self):
        return RichTextFieldPanel

    def render(self, name, value, attrs=None):
        if value is None:
            translated_value = None
        else:
            translated_value = expand_db_html(value, for_editor=True)
        return super(FroalaRichTextArea, self).render(name, translated_value, attrs)

    def render_js_init(self, id_, name, value):
        return "makeFroalaRichTextEditable({0}, {1});".format(
            json.dumps(id_),
            json.dumps(self.options)
        )

    def value_from_datadict(self, data, files, name):
        original_value = super(FroalaRichTextArea, self).value_from_datadict(data, files, name)
        if original_value is None:
            return None
        return DbWhitelister.clean(original_value)

    @property
    def media(self):
        js = [
            static('froala/vendor/js/froala_editor.pkgd.min.js'),
        ]

        css = [
            static('froala/css/wagtailfroala.css'),
            static('froala/vendor/css/froala_editor.pkgd.min.css'),
            '//cdnjs.cloudflare.com/ajax/libs/codemirror/5.3.0/codemirror.min.css',
            '//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.4.0/css/font-awesome.min.css',
        ]

        if getattr(settings, 'FROALA_CODEMIRROR', True):
            js.append('//cdnjs.cloudflare.com/ajax/libs/codemirror/5.3.0/codemirror.min.js')
            js.append('//cdnjs.cloudflare.com/ajax/libs/codemirror/5.3.0/mode/xml/xml.min.js')
            css.append('//cdnjs.cloudflare.com/ajax/libs/codemirror/5.3.0/codemirror.min.css')

        # Maintain the order of JavaScript files.
        js.append(static('froala/js/froala.js'))

        if getattr(settings, 'FROALA_FONT_AWESOME', True):
            css.append('//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.4.0/css/font-awesome.min.css')

        return Media(js=js, css={
            'all': css
        })



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='wagtailfroala',
    packages=['wagtailfroala'],
    version='0.2.9',
    author='Jayden Smith',
    author_email='jayden@intelliscale.com.au',
    include_package_data=True,
    install_requires=['Django>=1.8,<1.10', 'wagtail>=1.5,<1.6'],
    license='MIT License',
    description='Extends Wagtail to use the Froala WYSIWYG editor in RichTextFields/RichTextBlocks.',
    url='https://github.com/jaydensmith/wagtailfroala',
    long_description=README,
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
